__version__ = '0.1.0'

"""
usage: __init__.py [-h] [--clipboard] -f FILE -d DELAY

Write file/clipboard content on cursor

optional arguments:
  -h, --help   show this help message and exit

clipboard:
  --clipboard  copy from clipboard flag

file:
  -f FILE      input file path, not required for clipboard mode
  -d DELAY     delay in sec before writing to the cursor
"""

from argparse import ArgumentParser
import os.path
import pyautogui
import time
import sys
import pyperclip


def is_valid_file(parser, arg):
    if not os.path.exists(arg):
        parser.error(f"The file {arg} does not exist!")
    else:
        return open(arg, 'r')  # return an open file handle


def main():
    parser = ArgumentParser(
        description="Write file/clipboard content on cursor")

    clipboard_grp = parser.add_argument_group("clipboard")
    file_grp = parser.add_argument_group("file")

    clipboard_grp.add_argument(
        "--clipboard", action="store_true", help="copy from clipboard flag")

    file_grp.add_argument("-f", dest="filename", required="--clipboard" not in sys.argv,
                          help="input file path, not required for clipboard mode", metavar="FILE",
                          type=lambda x: is_valid_file(parser, x))

    file_grp.add_argument("-d", dest="delay", required=True,
                          help="delay in sec before writing to the cursor", type=int)
    args = parser.parse_args()

    if args.clipboard:
        print(f"Writing clipboard content to cursor in {args.delay} sec...")
        time.sleep(args.delay)

        clip_content = pyperclip.paste()
        pyautogui.write(clip_content)
    else:
        print(f"Writing file content to cursor in {args.delay} sec...")
        time.sleep(args.delay)

        file_content = args.filename.read()
        pyautogui.write(file_content)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['autotyper']

package_data = \
{'': ['*']}

install_requires = \
['PyAutoGUI>=0.9.52,<0.10.0', 'pyperclip>=1.8.1,<2.0.0']

entry_points = \
{'console_scripts': ['autotyper = autotyper:main']}

setup_kwargs = {
    'name': 'autotyper',
    'version': '2.0',
    'description': 'Paste the contents of a file to the cursor after a specified delay',
    'long_description': '# autotyper\n\nA simple command line tool to write the contents of a file to the cursor after a delay of few seconds. It uses\nthe `pyautogui` package to simulate the keystrokes to write out the file where the cursor is placed.\n\n\n## Installation\n\nMake sure you have Python3 installed on your system. \n\n```\npip install autotyper\n```\n\nYou will have the `autotyper` command available to go on your system.\n\n## Usage\n\n```\nWrite file/clipboard content on cursor\n\noptional arguments:\n  -h, --help   show this help message and exit\n\nclipboard:\n  --clipboard  copy from clipboard flag\n\nfile:\n  -f FILE      input file path, not required for clipboard mode\n  -d DELAY     delay in sec before writing to the cursor\n```\n\n```\n$ autotyper -f bubblesort.c -d 10\nWriting file content to cursor in 10 sec...\n```\n\nIn this time, position your cursor to where you want to type out the text, when the delay ends, \nthe content of the file will be written to the cursor. Can be used in online exams\nto write the content of a file, where copy paste is not allowed in the text box.\n\n```\n$ autotyper --clipboard -d 10\nWriting clipboard content to cursor in 10 sec...\n```\n\n\nThe content of your clipboard will be pasted on the cursor after the specified delay\n\n## License\n\nCopyright (c) **Junaid H. Rahim**. All rights reserved. Licensed under the MIT License\n\n[![forthebadge](https://forthebadge.com/images/badges/made-with-python.svg)](https://forthebadge.com)\n',
    'author': 'Junaid Rahim',
    'author_email': 'junaidrahim8d@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/junaidrahim/autotyper',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
